==> aipark-api-27.2-sources.jar: de/aipark/api/requestsResponse/getParkingAreasForTileWithOccupancyForDeparture/GetParkingAreasForTileWithOccupancyForDepartureRequest.java <==
package de.aipark.api.requestsResponse.getParkingAreasForTileWithOccupancyForDeparture;

import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.vividsolutions.jts.geom.Point;
import de.aipark.api.parkingarea.ParkingAreaDataFilter;
import de.aipark.api.requestsResponse.FiltersDeserializer;
import de.aipark.api.requestsResponse.Request;
import de.aipark.api.tile.Tile;
import io.swagger.annotations.ApiModelProperty;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by torgen on 26.09.17.
 */
public class GetParkingAreasForTileWithOccupancyForDepartureRequest extends Request {
    @ApiModelProperty(value = "tile of parking areas", dataType = "de.aipark.api.tile.Tile", required = true)
    private Tile tile;

    @ApiModelProperty(value = "list of filters", dataType = "List<ParkingAreaDataFilter>", required = true)
    @JsonDeserialize(using = FiltersDeserializer.class)
    private List<ParkingAreaDataFilter> filters = new ArrayList<ParkingAreaDataFilter>();

    @ApiModelProperty(value = "departure time", dataType = "java.lang.Long", required = true, example = "1476561575000")
    private Timestamp departureTimestamp;

    @ApiModelProperty(value = "departure position", required = true)
    public Point departurePosition;

    public GetParkingAreasForTileWithOccupancyForDepartureRequest() {
    }

    public GetParkingAreasForTileWithOccupancyForDepartureRequest(Tile tile, List<ParkingAreaDataFilter> filters, Timestamp departureTimestamp, Point departurePosition) {
        this.tile = tile;
        this.filters = filters;
        this.departureTimestamp = departureTimestamp;
        this.departurePosition = departurePosition;
    }

    public Timestamp getDepartureTimestamp() {
        return departureTimestamp;
    }

    public void setDepartureTimestamp(Timestamp departureTimestamp) {
        this.departureTimestamp = departureTimestamp;
    }

    public Tile getTile() {
        return tile;
    }

    public void setTile(Tile tile) {
        this.tile = tile;
    }

    public List<ParkingAreaDataFilter> getFilters() {
        return filters;
    }

    public void setFilters(List<ParkingAreaDataFilter> filters) {
        this.filters = filters;
    }

    public Point getDeparturePosition() {
        return departurePosition;
    }

    public void setDeparturePosition(Point departurePosition) {
        this.departurePosition = departurePosition;
    }
}

==> aipark-api-28.32-sources.jar: de/aipark/api/requestsResponse/getParkingAreasForTileWithOccupancyForDeparture/GetParkingAreasForTileWithOccupancyForDepartureRequest.java <==
package de.aipark.api.requestsResponse.getParkingAreasForTileWithOccupancyForDeparture;

import com.vividsolutions.jts.geom.Point;
import de.aipark.api.parkingarea.ParkingAreaDataFilter;
import de.aipark.api.tile.Tile;
import io.swagger.annotations.ApiModelProperty;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by torgen on 26.09.17.
 */
public class GetParkingAreasForTileWithOccupancyForDepartureRequest {
    @ApiModelProperty(value = "tile of parking areas", dataType = "de.aipark.api.tile.Tile", required = true)
    private Tile tile;

    @ApiModelProperty(value = "list of filters, filter CAR_PARK combines filters for types: \"CAR_PARK, AIRPORT,PARKING_DECK_AUTOMATED, UNDERGROUND_PARKING, UNDERGROUND_PARKING_AUTOMATED \"",
            dataType = "[Ljava.lang.String;", example = "[\"FREE\"]", required = true,
            allowableValues = ParkingAreaDataFilter.ALLOWED_VALUES_LIST)
    private List<ParkingAreaDataFilter> filters = new ArrayList<ParkingAreaDataFilter>();

    @ApiModelProperty(value = "departure time (UNIX time (since 1970) in milliseconds)", dataType = "java.lang.Long", required = true, example = "1476561575000")
    private Timestamp departureTimestamp;

    @ApiModelProperty(value = "departure position", required = true)
    public Point departurePosition;

    public GetParkingAreasForTileWithOccupancyForDepartureRequest() {
    }

    public GetParkingAreasForTileWithOccupancyForDepartureRequest(Tile tile, List<ParkingAreaDataFilter> filters, Timestamp departureTimestamp, Point departurePosition) {
        this.tile = tile;
        this.filters = filters;
        this.departureTimestamp = departureTimestamp;
        this.departurePosition = departurePosition;
    }

    public Timestamp getDepartureTimestamp() {
        return departureTimestamp;
    }

    public void setDepartureTimestamp(Timestamp departureTimestamp) {
        this.departureTimestamp = departureTimestamp;
    }

    public Tile getTile() {
        return tile;
    }

    public void setTile(Tile tile) {
        this.tile = tile;
    }

    public List<ParkingAreaDataFilter> getFilters() {
        return filters;
    }

    public void setFilters(List<ParkingAreaDataFilter> filters) {
        this.filters = filters;
    }

    public Point getDeparturePosition() {
        return departurePosition;
    }

    public void setDeparturePosition(Point departurePosition) {
        this.departurePosition = departurePosition;
    }

    @Override
    public String toString() {
        return "GetParkingAreasForTileWithOccupancyForDepartureRequest{" +
                "tile=" + tile +
                ", filters=" + filters +
                ", departureTimestamp=" + departureTimestamp +
                ", departurePosition=" + departurePosition +
                '}';
    }
}
